@@ -26,16 +26,6 @@ HOME_DIR = Path.home()
 DATA_DIR = HOME_DIR / DATA_DIR_NAME
 
 
-def get_version():
-    """ Look within setup.cfg for version = ... and within setup.py for __version__ = """
-    version = '0.0.0'
-    try:
-        return pkg_resources.get_distribution(PKG_NAME)
-    except Exception as e:
-        log.error(e)
-        log.warning(f"Unable to find {PKG_NAME} version so using {version}")
-    return version
-
 
 # SRC_DIR will be the lib/pythonX.X/site-packages directory if nessvec installed with pip from PyPi
 SRC_DIR = PKG_DIR.parent
@@ -49,6 +39,16 @@ SRC_DIR = PKG_DIR.parent
 REPO_DIR = SRC_DIR.parent
 
 
+# def get_version():
+#     """ Look within setup.cfg for version = ... and within setup.py for __version__ = """
+#     version = '0.0.0'
+#     try:
+#         return pkg_resources.get_distribution(PKG_NAME)
+#     except Exception as e:
+#         log.error(e)
+#         log.warning(f"Unable to find {PKG_NAME} version so using {version}")
+#     return version
+
 # def get_version():
 #     """ Look within setup.cfg for version = ... and within setup.py for __version__ = """
 #     try:
@@ -82,10 +82,10 @@ REPO_DIR = SRC_DIR.parent
 #         print(e)
 
 
-__version__ = get_version()
+# __version__ = get_version()
 
 
-log.debug(f'Running {__name__} version {__version__} ...')
+# log.debug(f'Running {__name__} version {__version__} ...')
 # LOGLEVEL = logging.ERROR
 
 
