@@ -675,7 +675,11 @@ def load_glove_hdf5(filepath=DEFAULT_HDF5_GLOVE_PATH, **kwargs):
 
 
 def load_word2vec_hdf5(filepath=DATA_DIR / DEFAULT_HDF5_WORD2VEC_FILENAME, **kwargs):
-    return load_hdf5_df(filepath, **kwargs)
+    try:
+        load_hdf5_df(filepath, **kwargs)
+    except Exception as e:
+        log.error(f"load_word2vec_hdf5({filepath}, **{kwargs})")
+        raise(e)
 
 
 def guess_algorithm_filepath(filepath=DEFAULT_EMBEDDING_ALGORITHM, **kwargs):
